**Example 1: 更新企业组织单元**



Input: 

```
tccli organization UpdateOrganizationNode --cli-unfold-argument  \
    --NodeId 123 \
    --Name "test" \
    --ParentNodeId 11
```

Output: 
```
{
    "Response": {
        "RequestId": "b46d2afe-6893-4529-bc96-2c82d9214957"
    }
}
```

